@@ -27,6 +27,7 @@
  * SIMcache
  * #coment
  * Dimensions=[<width> x <height>]
+ * Date=[<value in time_t format, or -1 if no embedded date>]
  * Checksum=[<value>]
  * MD5sum=[<32 character ascii text digest>]
  * SimilarityGrid[32 x 32]=<3072 bytes of data (1024 pixels in RGB format, 1 pixel is 24bits)>
@@ -51,8 +52,7 @@ CacheData *cache_sim_data_new(void)
 	CacheData *cd;
 
 	cd = g_new0(CacheData, 1);
-	cd->dimensions = FALSE;
-	cd->similarity = FALSE;
+	cd->date = -1;
 
 	return cd;
 }
@@ -81,6 +81,15 @@ static gint cache_sim_write_dimensions(FILE *f, CacheData *cd)
 	return TRUE;
 }
 
+static gint cache_sim_write_date(FILE *f, CacheData *cd)
+{
+	if (!f || !cd || !cd->have_date) return FALSE;
+
+	fprintf(f, "Date=[%ld]\n", cd->date);
+
+	return TRUE;
+}
+
 static gint cache_sim_write_checksum(FILE *f, CacheData *cd)
 {
 	if (!f || !cd || !cd->have_checksum) return FALSE;
@@ -157,6 +166,7 @@ gint cache_sim_data_save(CacheData *cd)
 
 	fprintf(f, "SIMcache\n#%s %s\n", PACKAGE, VERSION);
 	cache_sim_write_dimensions(f, cd);
+	cache_sim_write_date(f, cd);
 	cache_sim_write_checksum(f, cd);
 	cache_sim_write_md5sum(f, cd);
 	cache_sim_write_similarity(f, cd);
@@ -172,14 +182,16 @@ gint cache_sim_data_save(CacheData *cd)
  *-------------------------------------------------------------------
  */
 
-static gint cache_sim_read_skipline(FILE *f, int s)
+static gint cache_sim_read_comment(FILE *f, char *buf, int s, CacheData *cd)
 {
-	if (!f) return FALSE;
+	if (!f || !buf || !cd) return FALSE;
 
-	if (fseek(f, 0 - s, SEEK_CUR) == 0)
+	if (buf[0] != '#') return FALSE;
+
+	if (fseek(f, 0 - (s - 1), SEEK_CUR) == 0)
 		{
 		char b;
-		while (fread(&b, sizeof(b), 1, f) == 1)
+		while(fread(&b, sizeof(b), 1, f) == 1)
 			{
 			if (b == '\n') return TRUE;
 			}
@@ -189,15 +201,6 @@ static gint cache_sim_read_skipline(FILE *f, int s)
 	return FALSE;
 }
 
-static gint cache_sim_read_comment(FILE *f, char *buf, int s, CacheData *cd)
-{
-	if (!f || !buf || !cd) return FALSE;
-
-	if (s < 1 || buf[0] != '#') return FALSE;
-
-	return cache_sim_read_skipline(f, s - 1);
-}
-
 static gint cache_sim_read_dimensions(FILE *f, char *buf, int s, CacheData *cd)
 {
 	if (!f || !buf || !cd) return FALSE;
@@ -241,6 +244,46 @@ static gint cache_sim_read_dimensions(FILE *f, char *buf, int s, CacheData *cd)
 	return FALSE;
 }
 
+static gint cache_sim_read_date(FILE *f, char *buf, int s, CacheData *cd)
+{
+	if (!f || !buf || !cd) return FALSE;
+
+	if (s < 4 || strncmp("Date", buf, 4) != 0) return FALSE;
+
+	if (fseek(f, - s, SEEK_CUR) == 0)
+		{
+		char b;
+		char buf[1024];
+		gint p = 0;
+
+		b = 'X';
+		while (b != '[')
+			{
+			if (fread(&b, sizeof(b), 1, f) != 1) return FALSE;
+			}
+		while (b != ']' && p < 1023)
+			{
+			if (fread(&b, sizeof(b), 1, f) != 1) return FALSE;
+			buf[p] = b;
+			p++;
+			}
+
+		while (b != '\n')
+			{
+			if (fread(&b, sizeof(b), 1, f) != 1) break;
+			}
+
+		buf[p] = '\0';
+		cd->date = strtol(buf, NULL, 10);
+
+		cd->have_date = TRUE;
+
+		return TRUE;
+		}
+
+	return FALSE;
+}
+
 static gint cache_sim_read_checksum(FILE *f, char *buf, int s, CacheData *cd)
 {
 	if (!f || !buf || !cd) return FALSE;
@@ -382,14 +425,12 @@ static gint cache_sim_read_similarity(FILE *f, char *buf, int s, CacheData *cd)
 	return FALSE;
 }
 
-#define CACHE_LOAD_LINE_NOISE 8
-
 CacheData *cache_sim_data_load(const gchar *path)
 {
 	FILE *f;
 	CacheData *cd = NULL;
 	char buf[32];
-	gint success = CACHE_LOAD_LINE_NOISE;
+	gint success = TRUE;
 	gchar *pathl;
 
 	if (!path) return NULL;
@@ -407,38 +448,28 @@ CacheData *cache_sim_data_load(const gchar *path)
 	    strncmp(buf, "SIMcache", 8) != 0)
 		{
 		if (debug) printf("%s is not a cache file\n", cd->path);
-		success = 0;
+		success = FALSE;
 		}
 
-	while (success > 0)
+	while (success)
 		{
 		int s;
 		s = fread(&buf, sizeof(char), sizeof(buf), f);
 
 		if (s < 1)
 			{
-			success = 0;
+			success = FALSE;
 			}
 		else
 			{
 			if (!cache_sim_read_comment(f, buf, s, cd) &&
 			    !cache_sim_read_dimensions(f, buf, s, cd) &&
+			    !cache_sim_read_date(f, buf, s, cd) &&
 			    !cache_sim_read_checksum(f, buf, s, cd) &&
 			    !cache_sim_read_md5sum(f, buf, s, cd) &&
 			    !cache_sim_read_similarity(f, buf, s, cd))
 				{
-				if (!cache_sim_read_skipline(f, s))
-					{
-					success = 0;
-					}
-				else
-					{
-					success--;
-					}
-				}
-			else
-				{
-				success = CACHE_LOAD_LINE_NOISE;
+				success = FALSE;
 				}
 			}
 		}
@@ -446,6 +477,7 @@ CacheData *cache_sim_data_load(const gchar *path)
 	fclose(f);
 
 	if (!cd->dimensions &&
+	    !cd->have_date &&
 	    !cd->have_checksum &&
 	    !cd->have_md5sum &&
 	    !cd->similarity)
@@ -472,6 +504,14 @@ void cache_sim_data_set_dimensions(CacheData *cd, gint w, gint h)
 	cd->dimensions = TRUE;
 }
 
+void cache_sim_data_set_date(CacheData *cd, time_t date)
+{
+	if (!cd) return;
+
+	cd->date = date;
+	cd->have_date = TRUE;
+}
+
 void cache_sim_data_set_checksum(CacheData *cd, long checksum)
 {
 	if (!cd) return;
