@@ -1,6 +1,6 @@
 /*
  *  GQView
- *  (C) 2006 John Ellis
+ *  (C) 2004 John Ellis
  *
  *  Authors:
  *    Support for Exif file format, originally written by Eric Swalens.    
@@ -69,6 +69,7 @@
 
 #include "exif.h"
 
+#include "format_raw.h"
 #include "ui_fileops.h"
 
 
@@ -97,6 +98,7 @@ ExifFormatAttrib ExifFormatList[] = {
 
 /* tags that are special, or need special treatment */
 #define TAG_EXIFOFFSET          0x8769
+#define TAG_EXIFMAKERNOTE	0x927c
 
 
 /*
@@ -105,8 +107,6 @@ ExifFormatAttrib ExifFormatList[] = {
  *-----------------------------------------------------------------------------
  */
 
-#define EXIF_TEXT_LIST_END { -1, NULL }
-
 static ExifTextList ExifOrientationList[] = {
 	{ EXIF_ORIENTATION_UNKNOWN,	N_("unknown") },
 	{ EXIF_ORIENTATION_TOP_LEFT,	N_("top left") },
@@ -391,8 +391,7 @@ ExifMarker ExifKnownMarkersList[] = {
 { 0x9215, EXIF_FORMAT_RATIONAL_UNSIGNED, 1,	"ExposureIndex",	NULL, NULL },
 { 0x9216, EXIF_FORMAT_BYTE_UNSIGNED, 4,		"TIFF/EPStandardID",	NULL, NULL },
 
-	/* end is marked by 0 tag */
-{ 0x0000, EXIF_FORMAT_UNKNOWN, 0, NULL, NULL, NULL }
+EXIF_MARKER_LIST_END
 };
 
 ExifMarker ExifUnknownMarkersList[] = {
@@ -428,31 +427,7 @@ ExifFormattedText ExifFormattedList[] = {
 };
 
 
-/*
- *-----------------------------------------------------------------------------
- * misc
- *-----------------------------------------------------------------------------
- */
-
-typedef enum {
-	EXIF_BYTE_ORDER_INTEL,
-	EXIF_BYTE_ORDER_MOTOROLA
-} ExifByteOrder;
-
-
-#define EXIF_TIFF_MAX_LEVELS 4
-
-#define EXIF_TIFD_OFFSET_TAG 0
-#define EXIF_TIFD_OFFSET_FORMAT 2
-#define EXIF_TIFD_OFFSET_COUNT 4
-#define EXIF_TIFD_OFFSET_DATA 8
-#define EXIF_TIFD_SIZE 12
-
-
-static const ExifMarker *exif_marker_from_tag(guint16 tag);
-static int parse_IFD_table(ExifData *exif, unsigned char *tiff, guint offset,
-			   guint size, ExifByteOrder bo,
-			   gint level);
+static const ExifMarker *exif_marker_from_tag(guint16 tag, const ExifMarker *list);
 
 /*
  *-----------------------------------------------------------------------------
@@ -460,8 +435,8 @@ static int parse_IFD_table(ExifData *exif, unsigned char *tiff, guint offset,
  *-----------------------------------------------------------------------------
  */
 
-static ExifItem *exif_item_new(ExifFormatType format, guint tag,
-			       guint elements, const ExifMarker *marker)
+ExifItem *exif_item_new(ExifFormatType format, guint tag,
+			guint elements, const ExifMarker *marker)
 {
 	ExifItem *item;
 
@@ -587,7 +562,7 @@ static GString *string_append_raw_bytes(GString *string, gpointer data, gint ne)
 	return string;
 }
 
-static gchar *text_list_find_value(ExifTextList *list, guint value)
+gchar *exif_text_list_find_value(ExifTextList *list, guint value)
 {
 	gchar *result = NULL;
 	gint i;
@@ -605,34 +580,48 @@ static gchar *text_list_find_value(ExifTextList *list, guint value)
 
 /*
  *-------------------------------------------------------------------
- * byte order utils
+ * byte size utils
  *-------------------------------------------------------------------
  */
 
-/* note: the align_buf is used to avoid alignment issues (on sparc) */
-
-static guint16 exif_byte_get_int16(unsigned char *f, ExifByteOrder bo)
+guint16 exif_byte_get_int16(unsigned char *f, ExifByteOrder bo)
 {
-	guint16 align_buf;
-
-	memcpy(&align_buf, f, sizeof(guint16));
-
 	if (bo == EXIF_BYTE_ORDER_INTEL)
-		return GUINT16_FROM_LE(align_buf);
+		return GUINT16_FROM_LE(*(guint16*)f);
 	else
-		return GUINT16_FROM_BE(align_buf);
+		return GUINT16_FROM_BE(*(guint16*)f);
 }
 
-static guint32 exif_byte_get_int32(unsigned char *f, ExifByteOrder bo)
+guint32 exif_byte_get_int32(unsigned char *f, ExifByteOrder bo)
 {
-	guint32 align_buf;
-
-	memcpy(&align_buf, f, sizeof(guint32));
-
 	if (bo == EXIF_BYTE_ORDER_INTEL)
-		return GUINT32_FROM_LE(align_buf);
+		return GUINT32_FROM_LE(*(guint32*)f);
 	else
-		return GUINT32_FROM_BE(align_buf);
+		return GUINT32_FROM_BE(*(guint32*)f);
+}
+
+guint16 exif_byte_swab_int16(guint16 n, ExifByteOrder bo)
+{
+#if G_BYTE_ORDER == G_LITTLE_ENDIAN
+	if (bo == EXIF_BYTE_ORDER_MOTOROLA)
+#else
+	if (bo == EXIF_BYTE_ORDER_INTEL)
+#endif
+		return GUINT16_SWAP_LE_BE(n);
+	else
+		return n;
+}
+
+guint32 exif_byte_swab_int32(guint32 n, ExifByteOrder bo)
+{
+#if G_BYTE_ORDER == G_LITTLE_ENDIAN
+	if (bo == EXIF_BYTE_ORDER_MOTOROLA)
+#else
+	if (bo == EXIF_BYTE_ORDER_INTEL)
+#endif
+		return GUINT32_SWAP_LE_BE(n);
+	else
+		return n;
 }
 
 /*
@@ -641,16 +630,18 @@ static guint32 exif_byte_get_int32(unsigned char *f, ExifByteOrder bo)
  *-------------------------------------------------------------------
  */
 
-static const ExifMarker *exif_marker_from_tag(guint16 tag)
+static const ExifMarker *exif_marker_from_tag(guint16 tag, const ExifMarker *list)
 {
 	gint i = 0;
 
-	while (ExifKnownMarkersList[i].tag != 0 && ExifKnownMarkersList[i].tag != tag)
+	if (!list) return NULL;
+
+	while (list[i].tag != 0 && list[i].tag != tag)
 		{
 		i++;
 		}
 
-	return (ExifKnownMarkersList[i].tag == 0 ? NULL : &ExifKnownMarkersList[i]);
+	return (list[i].tag == 0 ? NULL : &list[i]);
 }
 
 static void rational_from_data(ExifRational *r, void *src, ExifByteOrder bo)
@@ -662,8 +653,8 @@ static void rational_from_data(ExifRational *r, void *src, ExifByteOrder bo)
 /* src_format and item->format must be compatible
  * and not overrun src or item->data.
  */
-static void exif_item_copy_data(ExifItem *item, void *src, guint len,
-				ExifFormatType src_format, ExifByteOrder bo)
+void exif_item_copy_data(ExifItem *item, void *src, guint len,
+			 ExifFormatType src_format, ExifByteOrder bo)
 {
 	gint bs;
 	gint ne;
@@ -751,9 +742,10 @@ static void exif_item_copy_data(ExifItem *item, void *src, guint len,
 		}
 }
 
-static gint parse_IFD_entry(ExifData *exif, unsigned char *tiff, guint offset,
-			    guint size, ExifByteOrder bo,
-			    gint level)
+static gint exif_parse_IFD_entry(ExifData *exif, unsigned char *tiff, guint offset,
+				 guint size, ExifByteOrder bo,
+				 gint level,
+				 const ExifMarker *list)
 {
 	guint tag;
 	guint format;
@@ -772,7 +764,7 @@ static gint parse_IFD_entry(ExifData *exif, unsigned char *tiff, guint offset,
 	/* Check tag type. If it does not match, either the format is wrong,
 	 * either it is a unknown tag; so it is not really an error.
 	 */
-	marker = exif_marker_from_tag(tag);
+	marker = exif_marker_from_tag(tag, list);
 	if (!marker)
 		{
 		if (format >= EXIF_FORMAT_COUNT)
@@ -841,17 +833,27 @@ static gint parse_IFD_entry(ExifData *exif, unsigned char *tiff, guint offset,
 	exif_item_copy_data(item, tiff + data_offset, data_length, format, bo);
 	exif->items = g_list_prepend(exif->items, item);
 
-	if (item->tag == TAG_EXIFOFFSET)
+	if (list == ExifKnownMarkersList)
 		{
-		parse_IFD_table(exif, tiff, data_val, size, bo, level + 1);
+		switch (item->tag)
+			{
+			case TAG_EXIFOFFSET:
+				exif_parse_IFD_table(exif, tiff, data_val, size, bo, level + 1, list);
+				break;
+			case TAG_EXIFMAKERNOTE:
+				format_exif_makernote_parse(exif, tiff, data_val, size, bo);
+				break;
+			}
 		}
 
 	return 0;
 }
 
-static int parse_IFD_table(ExifData *exif, unsigned char *tiff, guint offset,
-			   guint size, ExifByteOrder bo,
-			   gint level)
+gint exif_parse_IFD_table(ExifData *exif,
+			  unsigned char *tiff, guint offset,
+			  guint size, ExifByteOrder bo,
+			  gint level,
+			  const ExifMarker *list)
 {
 	guint count;
 	guint i;
@@ -870,7 +872,7 @@ static int parse_IFD_table(ExifData *exif, unsigned char *tiff, guint offset,
 
 	for (i = 0; i < count; i++)
 		{
-		parse_IFD_entry(exif, tiff, offset + i * EXIF_TIFD_SIZE, size, bo, level);
+		exif_parse_IFD_entry(exif, tiff, offset + i * EXIF_TIFD_SIZE, size, bo, level, list);
 		}
 
 	return 0;
@@ -878,44 +880,51 @@ static int parse_IFD_table(ExifData *exif, unsigned char *tiff, guint offset,
 
 /*
  *-------------------------------------------------------------------
- * tiff
+ * file formats
  *-------------------------------------------------------------------
  */
 
-static gint parse_TIFF(ExifData *exif, unsigned char *data, const guint len)
+gint exif_tiff_directory_offset(unsigned char *data, const guint len,
+				guint *offset, ExifByteOrder *bo)
+{
+	if (len < 8) return FALSE;
+
+	if (memcmp(data, "II", 2) == 0)
+		{
+		*bo = EXIF_BYTE_ORDER_INTEL;
+		}
+	else if (memcmp(data, "MM", 2) == 0)
+		{
+		*bo = EXIF_BYTE_ORDER_MOTOROLA;
+		}
+	else
+		{
+		return FALSE;
+		}
+
+	if (exif_byte_get_int16(data + 2, *bo) != 0x002A)
+		{
+		return FALSE;
+		}
+
+	*offset = exif_byte_get_int32(data + 4, *bo);
+
+	return (*offset < len);
+}
+
+gint exif_tiff_parse(ExifData *exif, unsigned char *tiff, guint size, ExifMarker *list)
 {
 	ExifByteOrder bo;
 	guint offset;
 
-	if (len < 8) return -1;
+	if (!exif_tiff_directory_offset(tiff, size, &offset, &bo)) return -1;
 
-	if (memcmp(data, "II", 2) == 0)
-		{
-		bo = EXIF_BYTE_ORDER_INTEL;
-		}
-	else if (memcmp(data, "MM", 2) == 0)
-		{
-		bo = EXIF_BYTE_ORDER_MOTOROLA;
-		}
-	else
-		{
-		return -1;
-		}
-
-	if (exif_byte_get_int16(data + 2, bo) != 0x002A)
-		{
-		return -1;
-		}
-
-	offset = exif_byte_get_int32(data + 4, bo);
-
-	return parse_IFD_table(exif, data, offset, len, bo, 0);
+	return exif_parse_IFD_table(exif, tiff, offset, size, bo, 0, list);
 }
 
-
 /*
  *-------------------------------------------------------------------
- * jpeg
+ * jpeg marker utils
  *-------------------------------------------------------------------
  */
 
@@ -923,13 +932,13 @@ static gint parse_TIFF(ExifData *exif, unsigned char *data, const guint len)
 #define MARKER_SOI		0xD8
 #define MARKER_APP1		0xE1
 
-static gint get_marker_size(unsigned char *data)
+static gint jpeg_get_marker_size(unsigned char *data)
 {
 	/* Size is always in Motorola byte order */
 	return exif_byte_get_int16(data + 2, EXIF_BYTE_ORDER_MOTOROLA);
 }
 
-static gint goto_next_marker(unsigned char **data, gint *size, gint *marker)
+static gint jpeg_goto_next_marker(unsigned char **data, gint *size, gint *marker)
 {
 	gint marker_size = 2;
 
@@ -941,7 +950,7 @@ static gint goto_next_marker(unsigned char **data, gint *size, gint *marker)
 	 */
 	if (*(*data + 1) != MARKER_SOI)
 		{
-		marker_size += get_marker_size(*data);
+		marker_size += jpeg_get_marker_size(*data);
 		}
 
 	*size -= marker_size;
@@ -956,17 +965,18 @@ static gint goto_next_marker(unsigned char **data, gint *size, gint *marker)
 	*data += marker_size;
 	if (**data != 0xFF) return -1;
 
-	if (get_marker_size(*data) + 2 > *size) return -1;
+	if (jpeg_get_marker_size(*data) + 2 > *size) return -1;
 
 	*marker = *(*data + 1);
 
 	return 0;
 }
 
-static gint parse_JPEG(ExifData *exif, unsigned char *data, gint size)
+
+static gint exif_parse_JPEG(ExifData *exif, unsigned char *data, guint size, ExifMarker *list)
 {
-	gint marker;
-	gint marker_size;
+	guint marker;
+	guint marker_size;
 
 	if (size < 4 || *data != 0xFF || *(data + 1) != MARKER_SOI)
 		{
@@ -974,7 +984,7 @@ static gint parse_JPEG(ExifData *exif, unsigned char *data, gint size)
 		}
 
 	do {
-		if (goto_next_marker(&data, &size, &marker) == -1)
+		if (jpeg_goto_next_marker(&data, &size, &marker) == -1)
 			{
 			break;
 			}
@@ -985,16 +995,22 @@ static gint parse_JPEG(ExifData *exif, unsigned char *data, gint size)
 		return -2;
 		}
 
-	marker_size = get_marker_size(data) - 2;
+	marker_size = jpeg_get_marker_size(data) - 2;
 		
 	if (marker_size < 6 || memcmp(data + 4, "Exif\x00\x00", 6) != 0)
 		{
 		return -2;
 		}
 
-	return parse_TIFF(exif, data + 10, marker_size - 6);
+	return exif_tiff_parse(exif, data + 10, marker_size - 6, list);
 }
 
+/*
+ *-------------------------------------------------------------------
+ * misc
+ *-------------------------------------------------------------------
+ */
+
 static gint map_file(const gchar *path, void **mapping, int *size)
 {
 	int fd;
@@ -1075,9 +1091,19 @@ ExifData *exif_read(const gchar *path)
 	exif = g_new0(ExifData, 1);
 	exif->items = NULL;
 
-	if ((res = parse_JPEG(exif, (unsigned char *)f, size)) == -2)
+	if ((res = exif_parse_JPEG(exif, (unsigned char *)f, size, ExifKnownMarkersList)) == -2)
 		{
-		res = parse_TIFF(exif, (unsigned char *)f, size);
+		res = exif_tiff_parse(exif, (unsigned char *)f, size, ExifKnownMarkersList);
+		}
+
+	if (res != 0)
+		{
+		guint32 offset = 0;
+		
+		if (format_raw_img_exif_offsets(f, size, NULL, &offset))
+			{
+			res = exif_tiff_parse(exif, (unsigned char*)f + offset, size - offset, ExifKnownMarkersList);
+			}
 		}
 
 	if (res != 0)
@@ -1155,7 +1181,7 @@ gchar *exif_item_get_data_as_text(ExifItem *item)
 					val = (unsigned char)(((signed char *)data)[0]);
 					}
 
-				result = text_list_find_value(marker->list, (guint)val);
+				result = exif_text_list_find_value(marker->list, (guint)val);
 				string = g_string_append(string, result);
 				g_free(result);
 				}
@@ -1172,21 +1198,21 @@ gchar *exif_item_get_data_as_text(ExifItem *item)
 				{
 				gchar *result;
 
-				result = text_list_find_value(marker->list, ((guint16 *)data)[0]);
+				result = exif_text_list_find_value(marker->list, ((unsigned short *)data)[0]);
 				string = g_string_append(string, result);
 				g_free(result);
 				}
 			else for (i = 0; i < ne; i++)
 				{
 				g_string_append_printf(string, "%s%hd", (i > 0) ? ", " : "",
-							((guint16 *)data)[i]);
+							((unsigned short *)data)[i]);
 				}
 			break;
 		case EXIF_FORMAT_LONG_UNSIGNED:
 			for (i = 0; i < ne; i++)
 				{
 				g_string_append_printf(string, "%s%ld", (i > 0) ? ", " : "",
-							(unsigned long int)((guint32 *)data)[i]);
+							((unsigned long *)data)[i]);
 				}
 			break;
 		case EXIF_FORMAT_RATIONAL_UNSIGNED:
@@ -1203,14 +1229,14 @@ gchar *exif_item_get_data_as_text(ExifItem *item)
 			for (i = 0; i < ne; i++)
 				{
 				g_string_append_printf(string, "%s%hd", (i > 0) ? ", " : "",
-							((gint16 *)data)[i]);
+							((short *)data)[i]);
 				}
 			break;
 		case EXIF_FORMAT_LONG:
 			for (i = 0; i < ne; i++)
 				{
 				g_string_append_printf(string, "%s%ld", (i > 0) ? ", " : "",
-							(long int)((gint32 *)data)[i]);
+							((long *)data)[i]);
 				}
 			break;
 		case EXIF_FORMAT_RATIONAL:
@@ -1252,20 +1278,20 @@ gint exif_item_get_integer(ExifItem *item, gint *value)
 	switch (item->format)
 		{
 		case EXIF_FORMAT_SHORT:
-			*value = (gint)(((gint16 *)(item->data))[0]);
+			*value = (gint)(((short *)(item->data))[0]);
 			return TRUE;
 			break;
 		case EXIF_FORMAT_SHORT_UNSIGNED:
-			*value = (gint)(((guint16 *)(item->data))[0]);
+			*value = (gint)(((unsigned short *)(item->data))[0]);
 			return TRUE;
 			break;
 		case EXIF_FORMAT_LONG:
-			*value = (gint)(((gint32 *)(item->data))[0]);
+			*value = (gint)(((long *)(item->data))[0]);
 			return TRUE;
 			break;
 		case EXIF_FORMAT_LONG_UNSIGNED:
 			/* FIXME: overflow possible */
-			*value = (gint)(((guint32 *)(item->data))[0]);
+			*value = (gint)(((unsigned long *)(item->data))[0]);
 			return TRUE;
 		default:
 			/* all other type return FALSE */
@@ -1467,7 +1493,7 @@ static gchar *exif_get_formatted_by_key(ExifData *exif, const gchar *key, gint *
 		if (!exif_get_integer(exif, "Flash", &n)) return NULL;
 
 		/* Exif 2.1 only defines first 3 bits */
-		if (n <= 0x07) return text_list_find_value(ExifFlashList, n);
+		if (n <= 0x07) return exif_text_list_find_value(ExifFlashList, n);
 
 		/* must be Exif 2.2 */
 		string = g_string_new("");
