@@ -51,13 +51,18 @@ typedef enum {
 	EXIF_FORMAT_DOUBLE		= 12
 } ExifFormatType;
 
+typedef enum {
+	EXIF_BYTE_ORDER_INTEL,
+	EXIF_BYTE_ORDER_MOTOROLA
+} ExifByteOrder;
+
 typedef struct _ExifFormatAttrib ExifFormatAttrib;
 struct _ExifFormatAttrib
 {
 	ExifFormatType type;
-	int size;
-	const char *short_name;
-	const char *description;
+	guint size;
+	const gchar *short_name;
+	const gchar *description;
 };
 
 /* the list of known tag data formats */
@@ -79,8 +84,8 @@ struct _ExifData
 typedef struct _ExifRational ExifRational;
 struct _ExifRational
 {
-	unsigned long int num;
-	unsigned long int den;
+	guint32 num;
+	guint32 den;
 };
 
 
@@ -91,35 +96,39 @@ typedef struct _ExifTextList ExifTextList;
 struct _ExifItem
 {
 	ExifFormatType format;
-	int tag;
+	guint tag;
 	const ExifMarker *marker;
-	int elements;
+	guint elements;
 	gpointer data;
-	int data_len;
+	guint data_len;
 };
 
 struct _ExifMarker
 {
-	int		tag;
+	guint		tag;
 	ExifFormatType	format;
-	int		components;
-	char		*key;
-	char		*description;
+	gint		components;
+	gchar		*key;
+	gchar		*description;
 	ExifTextList	*list;
 };
 
+#define EXIF_MARKER_LIST_END { 0x0000, EXIF_FORMAT_UNKNOWN, 0, NULL, NULL, NULL }
+
 struct _ExifTextList
 {
-	int value;
-	const char* description;
+	gint value;
+	const gchar* description;
 };
 
+#define EXIF_TEXT_LIST_END { -1, NULL }
+
 
 typedef struct _ExifFormattedText ExifFormattedText;
 struct _ExifFormattedText
 {
-	const char *key;
-	const char *description;
+	const gchar *key;
+	const gchar *description;
 };
 
 
@@ -190,4 +199,40 @@ const gchar *exif_get_description_by_key(const gchar *key);
 void exif_write_data_list(ExifData *exif, FILE *f, gint human_readable_list);
 
 
+
+/* These funcs for use by makernote/tiff parsers only */
+
+#define EXIF_TIFF_MAX_LEVELS 4
+
+#define EXIF_TIFD_OFFSET_TAG 0
+#define EXIF_TIFD_OFFSET_FORMAT 2
+#define EXIF_TIFD_OFFSET_COUNT 4
+#define EXIF_TIFD_OFFSET_DATA 8
+#define EXIF_TIFD_SIZE 12
+
+
+guint16 exif_byte_get_int16(unsigned char *f, ExifByteOrder bo);
+guint32 exif_byte_get_int32(unsigned char *f, ExifByteOrder bo);
+guint16 exif_byte_swab_int16(guint16 n, ExifByteOrder bo);
+guint32 exif_byte_swab_int32(guint32 n, ExifByteOrder bo);
+
+ExifItem *exif_item_new(ExifFormatType format, guint tag,
+			guint elements, const ExifMarker *marker);
+void exif_item_copy_data(ExifItem *item, void *src, guint len,
+			 ExifFormatType src_format, ExifByteOrder bo);
+
+gint exif_parse_IFD_table(ExifData *exif,
+			  unsigned char *tiff, guint offset,
+			  guint size, ExifByteOrder bo,
+			  gint level,
+			  const ExifMarker *list);
+
+gint exif_tiff_directory_offset(unsigned char *data, const guint len,
+				guint *offset, ExifByteOrder *bo);
+gint exif_tiff_parse(ExifData *exif, unsigned char *tiff, guint size, ExifMarker *list);
+
+gchar *exif_text_list_find_value(ExifTextList *list, guint value);
+
+
 #endif
+
