@@ -207,6 +207,13 @@ void filter_add_defaults(void)
 	filter_add_if_missing("ico", "Icon file", ".ico;.cur", FALSE);
 	filter_add_if_missing("ras", "Raster", ".ras", FALSE);
 	filter_add_if_missing("svg", "Scalable Vector Graphics", ".svg", FALSE);
+
+	/* These are the raw camera formats with embedded jpeg/exif.
+	 * (see format_raw.c)
+	 */
+	filter_add_if_missing("crw", "Canon raw format", ".crw;.cr2", TRUE);
+	filter_add_if_missing("raf", "Fujifilm raw format", ".raf", TRUE);
+	filter_add_if_missing("nef", "Nikon raw format", ".nef", TRUE);
 }
 
 static GList *filter_to_list(const gchar *extensions)
@@ -429,7 +436,7 @@ static void path_list_recursive_append(GList **list, GList *dirs)
 			d = path_list_filter(d, TRUE);
 			d = path_list_sort(d);
 			path_list_recursive_append(list, d);
-			g_list_free(d);
+			path_list_free(d);
 			}
 
 		work = work->next;
