@@ -1,6 +1,6 @@
 /*
  * GQview
- * (C) 2006 John Ellis
+ * (C) 2004 John Ellis
  *
  * Author: John Ellis
  *
@@ -133,6 +133,7 @@ extern gint thumb_max_width;
 extern gint thumb_max_height;
 extern gint enable_thumb_caching;
 extern gint enable_thumb_dirs;
+extern gint thumbnail_fast;
 extern gint use_xvpics_thumbnails;
 extern gint thumbnail_spec_standard;
 extern gint enable_metadata_dirs;
@@ -203,7 +204,7 @@ extern gint exif_rotate_enable;
  * This also doubles as the main.c header.
  */
 
-void window_set_icon(GtkWidget *window, const gchar *icon, const gchar *file);
+void window_set_icon(GtkWidget *window, const char **icon, const gchar *file);
 gint window_maximized(GtkWidget *window);
 
 gdouble get_zoom_increment(void);
