@@ -52,6 +52,8 @@ void image_change_from_collection(ImageWindow *imd, CollectionData *cd, CollectI
 CollectionData *image_get_collection(ImageWindow *imd, CollectInfo **info);
 void image_change_from_image(ImageWindow *imd, ImageWindow *source);
 
+GdkPixbuf *image_get_pixbuf(ImageWindow *imd);
+
 /* manipulation */
 void image_area_changed(ImageWindow *imd, gint x, gint y, gint width, gint height);
 void image_reload(ImageWindow *imd);
@@ -106,6 +108,9 @@ void image_set_image_as_tiles(ImageWindow *imd, gint width, gint height,
 			      gpointer data,
 			      gdouble zoom);
 
+/* reset default options */
+void image_options_sync(void);
+
 
 #endif
 
