@@ -1,6 +1,6 @@
 /*
  * GQview
- * (C) 2006 John Ellis
+ * (C) 2004 John Ellis
  *
  * Author: John Ellis
  *
@@ -23,8 +23,7 @@
 #include "image-overlay.h"
 #include "info.h"
 #include "menu.h"
-#include "pixbuf_util.h"
-#include "print.h"
+#include "pixbuf-renderer.h"
 #include "slideshow.h"
 #include "utilops.h"
 #include "ui_bookmark.h"
@@ -33,6 +32,8 @@
 
 #include <gdk/gdkkeysyms.h> /* for keyboard values */
 
+#include "icons/view.xpm"
+
 
 typedef struct _ViewWindow ViewWindow;
 struct _ViewWindow
@@ -317,7 +318,7 @@ static void view_window_menu_pos_cb(GtkMenu *menu, gint *x, gint *y, gboolean *p
 	ImageWindow *imd;
 
 	imd = view_window_active_image(vw);
-	gdk_window_get_origin(imd->image->window, x, y);
+	gdk_window_get_origin(imd->pr->window, x, y);
 	popup_menu_position_clamp(menu, x, y, 0);
 }
 
@@ -325,52 +326,150 @@ static gint view_window_key_press_cb(GtkWidget *widget, GdkEventKey *event, gpoi
 {
 	ViewWindow *vw = data;
 	ImageWindow *imd;
-	gint stop_signal;
+	gint stop_signal = FALSE;
 	GtkWidget *menu;
 	gint x = 0;
 	gint y = 0;
 
 	imd = view_window_active_image(vw);
 
-	stop_signal = TRUE;
 	switch (event->keyval)
 		{
 		case GDK_Left: case GDK_KP_Left:
 			x -= 1;
+			stop_signal = TRUE;
 			break;
 		case GDK_Right: case GDK_KP_Right:
 			x += 1;
+			stop_signal = TRUE;
 			break;
 		case GDK_Up: case GDK_KP_Up:
 			y -= 1;
+			stop_signal = TRUE;
 			break;
 		case GDK_Down: case GDK_KP_Down:
 			y += 1;
-			break;
-		default:
-			stop_signal = FALSE;
+			stop_signal = TRUE;
 			break;
 		}
 
-	if (x != 0 || y!= 0)
+	if ( !(event->state & GDK_CONTROL_MASK) )
+	    switch (event->keyval)
 		{
-		if (event->state & GDK_SHIFT_MASK)
-			{
-			x *= 3;
-			y *= 3;
-			}
-
-		keyboard_scroll_calc(&x, &y, event);
-		image_scroll(imd, x, y);
+		case GDK_Page_Up: case GDK_KP_Page_Up:
+		case GDK_BackSpace:
+		case 'B': case 'b':
+			view_step_prev(vw);
+			stop_signal = TRUE;
+			break;
+		case GDK_Page_Down: case GDK_KP_Page_Down:
+		case GDK_space:
+		case 'N': case 'n':
+			view_step_next(vw);
+			stop_signal = TRUE;
+			break;
+		case GDK_Home: case GDK_KP_Home:
+			view_step_to_end(vw, FALSE);
+			stop_signal = TRUE;
+			break;
+		case GDK_End: case GDK_KP_End:
+			view_step_to_end(vw, TRUE);
+			stop_signal = TRUE;
+			break;
+		case '+': case '=': case GDK_KP_Add:
+			image_zoom_adjust(imd, get_zoom_increment());
+			break;
+		case '-': case GDK_KP_Subtract:
+			image_zoom_adjust(imd, -get_zoom_increment());
+			break;
+		case 'X': case 'x': case GDK_KP_Multiply:
+			image_zoom_set(imd, 0.0);
+			break;
+		case 'Z': case 'z': case GDK_KP_Divide: case '1':
+			image_zoom_set(imd, 1.0);
+			break;
+		case '2':
+			image_zoom_set(imd, 2.0);
+			break;
+		case '3':
+			image_zoom_set(imd, 3.0);
+			break;
+		case '4':
+			image_zoom_set(imd, 4.0);
+			break;
+		case '7':
+			image_zoom_set(imd, -4.0);
+			break;
+		case '8':
+			image_zoom_set(imd, -3.0);
+			break;
+		case '9':
+			image_zoom_set(imd, -2.0);
+			break;
+		case 'W': case 'w':
+			image_zoom_set_fill_geometry(imd, FALSE);
+			break;
+		case 'H': case 'h':
+			image_zoom_set_fill_geometry(imd, TRUE);
+			break;
+		case 'R': case 'r':
+			image_reload(imd);
+			break;
+		case 'S': case 's':
+			if (vw->ss)
+				view_slideshow_stop(vw);
+			else
+				view_slideshow_start(vw);
+			stop_signal = TRUE;
+			break;
+		case 'P': case 'p':
+			slideshow_pause_toggle(vw->ss);
+			break;
+		case 'F': case 'f':
+		case 'V': case 'v':
+			view_fullscreen_toggle(vw, FALSE);
+			stop_signal = TRUE;
+			break;
+		case 'I': case 'i':
+			view_overlay_toggle(vw);
+			break;
+		case ']':
+			image_alter(imd, ALTER_ROTATE_90);
+			stop_signal = TRUE;
+			break;
+		case '[':
+			image_alter(imd, ALTER_ROTATE_90_CC);
+			stop_signal = TRUE;
+			break;
+		case GDK_Delete: case GDK_KP_Delete:
+			if (enable_delete_key)
+				{
+				file_util_delete(image_get_path(imd), NULL, imd->widget);
+				stop_signal = TRUE;
+				}
+			break;
+		case GDK_Escape:
+			if (vw->fs)
+				{
+				view_fullscreen_toggle(vw, TRUE);
+				}
+			else
+				{
+				gtk_widget_destroy(vw->window);
+				}
+			stop_signal = TRUE;
+			break;
+		case GDK_Menu:
+		case GDK_F10:
+			menu = view_popup_menu(vw);
+			gtk_menu_popup(GTK_MENU(menu), NULL, NULL, view_window_menu_pos_cb, vw, 0, GDK_CURRENT_TIME);
+			stop_signal = TRUE;
+			break;
 		}
 
-	if (stop_signal) return stop_signal;
-
 	if (event->state & GDK_CONTROL_MASK)
 		{
 		gint n = -1;
-
-		stop_signal = TRUE;
 		switch (event->keyval)
 			{
 			case '1':
@@ -405,25 +504,27 @@ static gint view_window_key_press_cb(GtkWidget *widget, GdkEventKey *event, gpoi
 				break;
 			case 'C': case 'c':
 				file_util_copy(image_get_path(imd), NULL, NULL, imd->widget);
+				stop_signal = TRUE;
 				break;
 			case 'M': case 'm':
 				file_util_move(image_get_path(imd), NULL, NULL, imd->widget);
+				stop_signal = TRUE;
 				break;
 			case 'R': case 'r':
 				file_util_rename(image_get_path(imd), NULL, imd->widget);
+				stop_signal = TRUE;
 				break;
 			case 'D': case 'd':
 				file_util_delete(image_get_path(imd), NULL, imd->widget);
+				stop_signal = TRUE;
 				break;
 			case 'P': case 'p':
 				info_window_new(image_get_path(imd), NULL);
+				stop_signal = TRUE;
 				break;
 			case 'W': case 'w':
 				view_window_close(vw);
 				break;
-			default:
-				stop_signal = FALSE;
-				break;
 			}
 		if (n != -1)
 			{
@@ -437,148 +538,31 @@ static gint view_window_key_press_cb(GtkWidget *widget, GdkEventKey *event, gpoi
 		}
 	else if (event->state & GDK_SHIFT_MASK)
 		{
-		stop_signal = TRUE;
 		switch (event->keyval)
 			{
 			case 'R': case 'r':
 				image_alter(imd, ALTER_ROTATE_180);
+				stop_signal = TRUE;
 				break;
 			case 'M': case 'm':
 				image_alter(imd, ALTER_MIRROR);
+				stop_signal = TRUE;
 				break;
 			case 'F': case 'f':
 				image_alter(imd, ALTER_FLIP);
-				break;
-			case 'P': case 'p':
-				{
-				const gchar *path;
-
-				view_fullscreen_toggle(vw, TRUE);
-				imd = view_window_active_image(vw);
-				path = image_get_path(imd);
-				print_window_new(path,
-						 (path) ? g_list_append(NULL, g_strdup(path)) : NULL,
-						 path_list_copy(vw->list), vw->window);
-				}
+				stop_signal = TRUE;
 				break;
 			default:
-				stop_signal = FALSE;
 				break;
 			}
+		x *= 3;
+		y *= 3;
 		}
-	else 
+
+	if (x != 0 || y!= 0)
 		{
-		stop_signal = TRUE;
-		switch (event->keyval)
-			{
-			case GDK_Page_Up: case GDK_KP_Page_Up:
-			case GDK_BackSpace:
-			case 'B': case 'b':
-				view_step_prev(vw);
-				break;
-			case GDK_Page_Down: case GDK_KP_Page_Down:
-			case GDK_space:
-			case 'N': case 'n':
-				view_step_next(vw);
-				break;
-			case GDK_Home: case GDK_KP_Home:
-				view_step_to_end(vw, FALSE);
-				break;
-			case GDK_End: case GDK_KP_End:
-				view_step_to_end(vw, TRUE);
-				break;
-			case '+': case '=': case GDK_KP_Add:
-				image_zoom_adjust(imd, get_zoom_increment());
-				break;
-			case '-': case GDK_KP_Subtract:
-				image_zoom_adjust(imd, -get_zoom_increment());
-				break;
-			case 'X': case 'x': case GDK_KP_Multiply:
-				image_zoom_set(imd, 0.0);
-				break;
-			case 'Z': case 'z': case GDK_KP_Divide: case '1':
-				image_zoom_set(imd, 1.0);
-				break;
-			case '2':
-				image_zoom_set(imd, 2.0);
-				break;
-			case '3':
-				image_zoom_set(imd, 3.0);
-				break;
-			case '4':
-				image_zoom_set(imd, 4.0);
-				break;
-			case '7':
-				image_zoom_set(imd, -4.0);
-				break;
-			case '8':
-				image_zoom_set(imd, -3.0);
-				break;
-			case '9':
-				image_zoom_set(imd, -2.0);
-				break;
-			case 'W': case 'w':
-				image_zoom_set_fill_geometry(imd, FALSE);
-				break;
-			case 'H': case 'h':
-				image_zoom_set_fill_geometry(imd, TRUE);
-				break;
-			case 'R': case 'r':
-				image_reload(imd);
-				break;
-			case 'S': case 's':
-				if (vw->ss)
-					{
-					view_slideshow_stop(vw);
-					}
-				else
-					{
-					view_slideshow_start(vw);
-					}
-				break;
-			case 'P': case 'p':
-				slideshow_pause_toggle(vw->ss);
-				break;
-			case 'F': case 'f':
-			case 'V': case 'v':
-			case GDK_F11:
-				view_fullscreen_toggle(vw, FALSE);
-				break;
-			case 'I': case 'i':
-				view_overlay_toggle(vw);
-				break;
-			case ']':
-				image_alter(imd, ALTER_ROTATE_90);
-				break;
-			case '[':
-				image_alter(imd, ALTER_ROTATE_90_CC);
-				break;
-			case GDK_Delete: case GDK_KP_Delete:
-				if (enable_delete_key)
-					{
-					file_util_delete(image_get_path(imd), NULL, imd->widget);
-					}
-				break;
-			case GDK_Escape:
-				if (vw->fs)
-					{
-					view_fullscreen_toggle(vw, TRUE);
-					}
-				else
-					{
-					view_window_close(vw);
-					}
-				break;
-			case GDK_Menu:
-			case GDK_F10:
-				menu = view_popup_menu(vw);
-				gtk_menu_popup(GTK_MENU(menu), NULL, NULL,
-					       view_window_menu_pos_cb, vw, 0, GDK_CURRENT_TIME);
-				break;
-			default:
-				stop_signal = FALSE;
-				break;
-			}
+		keyboard_scroll_calc(&x, &y, event);
+		image_scroll(imd, x, y);
 		}
 
 	return stop_signal;
@@ -741,28 +725,8 @@ static void view_slideshow_prev(ViewWindow *vw)
 static void view_slideshow_stop_func(SlideShowData *fs, gpointer data)
 {
 	ViewWindow *vw = data;
-	GList *work;
-	const gchar *path;
 
 	vw->ss = NULL;
-
-	work = vw->list;
-	path = image_get_path(view_window_active_image(vw));
-	while (work)
-		{
-		gchar *temp;
-
-		temp = work->data;
-		if (strcmp(path, temp) == 0)
-			{
-			vw->list_pointer = work;
-			work = NULL;
-			}
-		else
-			{
-			work = work->next;
-			}
-		}
 }
 
 static void view_slideshow_start(ViewWindow *vw)
@@ -795,24 +759,15 @@ static void view_slideshow_stop(ViewWindow *vw)
 	if (vw->ss) slideshow_free(vw->ss);
 }
 
-static void view_window_destroy_cb(GtkWidget *widget, gpointer data)
+static void view_window_close(ViewWindow *vw)
 {
-	ViewWindow *vw = data;
-
 	view_window_list = g_list_remove(view_window_list, vw);
 
-	view_slideshow_stop(vw);
-	fullscreen_stop(vw->fs);
-
-	path_list_free(vw->list);
-	g_free(vw);
-}
-
-static void view_window_close(ViewWindow *vw)
-{
 	view_slideshow_stop(vw);
 	view_fullscreen_toggle(vw, TRUE);
 	gtk_widget_destroy(vw->window);
+	path_list_free(vw->list);
+	g_free(vw);
 }
 
 static gint view_window_delete_cb(GtkWidget *w, GdkEventAny *event, gpointer data)
@@ -851,7 +806,7 @@ static ViewWindow *real_view_window_new(const gchar *path, GList *list, Collecti
         gtk_window_set_wmclass(GTK_WINDOW(vw->window), "view", "GQview");
         gtk_container_set_border_width(GTK_CONTAINER(vw->window), 0);
 
-	window_set_icon(vw->window, PIXBUF_INLINE_ICON_VIEW, NULL);
+	window_set_icon(vw->window, (const gchar **)view_xpm, NULL);
 
 	vw->imd = image_new(FALSE);
 
@@ -869,8 +824,6 @@ static ViewWindow *real_view_window_new(const gchar *path, GList *list, Collecti
 
 	view_image_set_buttons(vw, vw->imd);
 
-	g_signal_connect(G_OBJECT(vw->window), "destroy",
-			 G_CALLBACK(view_window_destroy_cb), vw);
 	g_signal_connect(G_OBJECT(vw->window), "delete_event",
 			 G_CALLBACK(view_window_delete_cb), vw);
 	g_signal_connect(G_OBJECT(vw->window), "key_press_event",
@@ -904,13 +857,11 @@ static ViewWindow *real_view_window_new(const gchar *path, GList *list, Collecti
 
 	if (image_zoom_get(vw->imd) == 0.0)
 		{
-		w = vw->imd->image_width;
-		h = vw->imd->image_height;
+		pixbuf_renderer_get_image_size(PIXBUF_RENDERER(vw->imd->pr), &w, &h);
 		}
 	else
 		{
-		w = vw->imd->width;
-		h = vw->imd->height;
+		pixbuf_renderer_get_scaled_size(PIXBUF_RENDERER(vw->imd->pr), &w, &h);
 		}
 	if (limit_window_size)
 		{
@@ -927,7 +878,7 @@ static ViewWindow *real_view_window_new(const gchar *path, GList *list, Collecti
 	req_size.height = h;
 	gtk_widget_size_allocate(GTK_WIDGET(vw->window), &req_size);
 
-	gtk_widget_set_size_request(vw->imd->image, w, h);
+	gtk_widget_set_size_request(vw->imd->pr, w, h);
 
 	gtk_widget_show(vw->window);
 
@@ -1033,13 +984,9 @@ gint view_window_find_image(ImageWindow *imd, gint *index, gint *total)
 			if (vw->ss)
 				{
 				gint n;
-				gint t;
-
 				n = g_list_length(vw->ss->list_done);
-				t = n + g_list_length(vw->ss->list);
-				if (n == 0) n = t;
 				if (index) *index = n - 1;
-				if (total) *total = t;
+				if (total) *total = n + g_list_length(vw->ss->list);
 				}
 			else
 				{
@@ -1431,7 +1378,7 @@ static void view_window_get_dnd_data(GtkWidget *widget, GdkDragContext *context,
 	ViewWindow *vw = data;
 	ImageWindow *imd;
 
-	if (gtk_drag_get_source_widget(context) == vw->imd->image) return;
+	if (gtk_drag_get_source_widget(context) == vw->imd->pr) return;
 
 	imd = vw->imd;
 
@@ -1445,7 +1392,7 @@ static void view_window_get_dnd_data(GtkWidget *widget, GdkDragContext *context,
 			{
 			GList *work;
 
-			list = uri_list_from_text((gchar *)selection_data->data, TRUE);
+			list = uri_list_from_text(selection_data->data, TRUE);
 
 			work = list;
 			while (work)
@@ -1534,7 +1481,7 @@ static void view_window_set_dnd_data(GtkWidget *widget, GdkDragContext *context,
 		if (text)
 			{
 			gtk_selection_data_set (selection_data, selection_data->target,
-						8, (guchar *)text, len);
+						8, text, len);
 			g_free(text);
 			}
 		}
@@ -1551,17 +1498,17 @@ static void view_window_dnd_init(ViewWindow *vw)
 
 	imd = vw->imd;
 
-	gtk_drag_source_set(imd->image, GDK_BUTTON2_MASK,
+	gtk_drag_source_set(imd->pr, GDK_BUTTON2_MASK,
 			    dnd_file_drag_types, dnd_file_drag_types_count,
 			    GDK_ACTION_COPY | GDK_ACTION_MOVE | GDK_ACTION_LINK);
-	g_signal_connect(G_OBJECT(imd->image), "drag_data_get",
+	g_signal_connect(G_OBJECT(imd->pr), "drag_data_get",
 			 G_CALLBACK(view_window_set_dnd_data), vw);
 
-	gtk_drag_dest_set(imd->image,
+	gtk_drag_dest_set(imd->pr,
 			  GTK_DEST_DEFAULT_MOTION | GTK_DEST_DEFAULT_DROP,
 			  dnd_file_drop_types, dnd_file_drop_types_count,
                           GDK_ACTION_COPY | GDK_ACTION_MOVE | GDK_ACTION_LINK);
-	g_signal_connect(G_OBJECT(imd->image), "drag_data_received",
+	g_signal_connect(G_OBJECT(imd->pr), "drag_data_received",
 			 G_CALLBACK(view_window_get_dnd_data), vw);
 }
 
