@@ -17,6 +17,7 @@
 #include "layout_image.h"
 #include "layout_util.h"
 #include "menu.h"
+#include "pixbuf-renderer.h"
 #include "pixbuf_util.h"
 #include "view_dir_list.h"
 #include "view_dir_tree.h"
@@ -28,11 +29,12 @@
 #include "ui_misc.h"
 #include "ui_tabcomp.h"
 
+#include "icons/tools.xpm"
 
 #define MAINWINDOW_DEF_WIDTH 700
 #define MAINWINDOW_DEF_HEIGHT 500
 
-#define MAIN_WINDOW_DIV_HPOS -1
+#define MAIN_WINDOW_DIV_HPOS 270
 #define MAIN_WINDOW_DIV_VPOS 200
 
 #define TOOLWINDOW_DEF_WIDTH 260
@@ -225,8 +227,6 @@ static void layout_sort_menu_cb(GtkWidget *widget, gpointer data)
 	LayoutWindow *lw;
 	SortType type;
 
-	if (!gtk_check_menu_item_get_active(GTK_CHECK_MENU_ITEM(widget))) return;
-
 	lw = submenu_item_get_data(widget);
 	if (!lw) return;
 
@@ -257,15 +257,9 @@ static void layout_sort_button_press_cb(GtkWidget *widget, gpointer data)
 
 	menu = submenu_add_sort(NULL, G_CALLBACK(layout_sort_menu_cb), lw, FALSE, FALSE, TRUE, lw->sort_method);
 
-	/* take ownership of menu */
-#ifdef GTK_OBJECT_FLOATING
-	/* GTK+ < 2.10 */
+	/* apparently the menu is never sunk, even on a popup */
 	g_object_ref(G_OBJECT(menu));
 	gtk_object_sink(GTK_OBJECT(menu));
-#else
-	/* GTK+ >= 2.10 */
-	g_object_ref_sink(G_OBJECT(menu));
-#endif
 
         /* ascending option */
 	menu_item_add_divider(menu);
@@ -406,8 +400,11 @@ void layout_status_update_image(LayoutWindow *lw)
 		}
 	else
 		{
+		gint width, height;
+
+		pixbuf_renderer_get_image_size(PIXBUF_RENDERER(lw->image->pr), &width, &height);
 		text = g_strdup_printf(_("( %d x %d ) %s bytes"),
-				       lw->image->image_width, lw->image->image_height, b);
+				       width, height, b);
 		}
 
 	gtk_label_set_text(GTK_LABEL(lw->info_details), text);
@@ -1106,7 +1103,7 @@ static void layout_tools_setup(LayoutWindow *lw, GtkWidget *tools, GtkWidget *fi
         	gtk_window_set_wmclass(GTK_WINDOW(lw->tools), "tools", "GQview");
         	gtk_container_set_border_width(GTK_CONTAINER(lw->tools), 0);
 
-		window_set_icon(lw->tools, PIXBUF_INLINE_ICON_TOOLS, NULL);
+		window_set_icon(lw->tools, (const gchar **)tools_xpm, NULL);
 
 		new_window = TRUE;
 		}
@@ -1586,7 +1583,6 @@ void layout_free(LayoutWindow *lw)
 
 	layout_bars_close(lw);
 
-	if (lw->tooltips) g_object_unref(G_OBJECT(lw->tooltips));
 	gtk_widget_destroy(lw->window);
 
 	g_free(lw->path);
@@ -1698,18 +1694,6 @@ LayoutWindow *layout_new(const gchar *path, gint popped, gint hidden)
 
 	layout_keyboard_init(lw, lw->window);
 
-	lw->tooltips = gtk_tooltips_new();
-
-	/* take ownership of tooltips */
-#ifdef GTK_OBJECT_FLOATING
-	/* GTK+ < 2.10 */
-	g_object_ref(G_OBJECT(lw->tooltips));
-	gtk_object_sink(GTK_OBJECT(lw->tooltips));
-#else
-	/* GTK+ >= 2.10 */
-	g_object_ref_sink(G_OBJECT(lw->tooltips));
-#endif
-
 	lw->main_box = gtk_vbox_new(FALSE, 0);
 	gtk_container_add(GTK_CONTAINER(lw->window), lw->main_box);
 	gtk_widget_show(lw->main_box);
