@@ -26,13 +26,10 @@ GdkPixbuf *pixbuf_inline(const gchar *key);
 #define PIXBUF_INLINE_FOLDER_UP		"folder_up"
 #define PIXBUF_INLINE_SCROLLER		"scroller"
 #define PIXBUF_INLINE_BROKEN		"broken"
-#define PIXBUF_INLINE_ICON		"icon"
 #define PIXBUF_INLINE_LOGO		"logo"
 
-#define PIXBUF_INLINE_ICON_BOOK		"icon_book"
-#define PIXBUF_INLINE_ICON_CONFIG	"icon_config"
-#define PIXBUF_INLINE_ICON_TOOLS	"icon_tools"
-#define PIXBUF_INLINE_ICON_VIEW		"icon_view"
+#define PIXBUF_INLINE_ICON_FLOAT	"icon_float"
+#define PIXBUF_INLINE_ICON_THUMB	"icon_thumb"
 
 
 GdkPixbuf *pixbuf_copy_rotate_90(GdkPixbuf *src, gint counter_clockwise);
@@ -65,6 +62,30 @@ void pixbuf_draw_layout(GdkPixbuf *pixbuf, PangoLayout *layout, GtkWidget *widge
 			guint8 r, guint8 g, guint8 b, guint8 a);
 
 
+void pixbuf_draw_triangle(GdkPixbuf *pb,
+			  gint clip_x, gint clip_y, gint clip_w, gint clip_h,
+			  gint x1, gint y1, gint x2, gint y2, gint x3, gint y3,
+			  guint8 r, guint8 g, guint8 b, guint8 a);
+
+void pixbuf_draw_line(GdkPixbuf *pb,
+		      gint clip_x, gint clip_y, gint clip_w, gint clip_h,
+		      gint x1, gint y1, gint x2, gint y2,
+		      guint8 r, guint8 g, guint8 b, guint8 a);
+
+void pixbuf_draw_shadow(GdkPixbuf *pb,
+			gint clip_x, gint clip_y, gint clip_w, gint clip_h,
+			gint x, gint y, gint w, gint h, gint border,
+			guint8 r, guint8 g, guint8 b, guint8 a);
+
+/* clipping utils */
+
+gint util_clip_region(gint x, gint y, gint w, gint h,
+		      gint clip_x, gint clip_y, gint clip_w, gint clip_h,
+		      gint *rx, gint *ry, gint *rw, gint *rh);
+void util_clip_triangle(gint x1, gint y1, gint x2, gint y2, gint x3, gint y3,
+			gint *rx, gint *ry, gint *rw, gint *rh);
+
+
 #endif
 
 
