@@ -67,10 +67,6 @@
 #define PRINT_PS_DPI_MIN 150.0
 /* method to use when scaling down image data */
 #define PRINT_PS_MAX_INTERP GDK_INTERP_BILINEAR
-/* color to use as mask when printing transparent images */
-#define PRINT_PS_MASK_R 255
-#define PRINT_PS_MASK_G 255
-#define PRINT_PS_MASK_B 255
 
 /* padding between objects */
 #define PRINT_TEXT_PADDING 3.0
@@ -618,7 +614,7 @@ static void print_window_layout_size(PrintWindow *pw)
 
 	sw = print_preview_unit(width);
 	sh = print_preview_unit(height);
-	pixbuf = pw->layout_image->pixbuf;
+	pixbuf = image_get_pixbuf(pw->layout_image);
 	if (!pixbuf ||
 	    gdk_pixbuf_get_width(pixbuf) != sw ||
 	    gdk_pixbuf_get_height(pixbuf) != sh)
@@ -1236,7 +1232,6 @@ static gint print_job_ps_page_image(PrintWindow *pw, GdkPixbuf *pixbuf,
 	gint i, j;
 	gint c;
 	guchar *p;
-	guchar bps_buf[3];
 	gint ret;
 
 	if (!pixbuf) return TRUE;
@@ -1285,17 +1280,7 @@ static gint print_job_ps_page_image(PrintWindow *pw, GdkPixbuf *pixbuf,
 		p = pix + j * rowstride;
 		for (i = 0; i < sw; i++)
 			{
-			if (bps == 3)
-				{
-				print_job_ps_page_image_pixel(f, p);
-				}
-			else
-				{
-				bps_buf[0] = (p[0] * p[3] + PRINT_PS_MASK_R * (256 - p[3])) >> 8;
-				bps_buf[1] = (p[1] * p[3] + PRINT_PS_MASK_G * (256 - p[3])) >> 8;
-				bps_buf[2] = (p[2] * p[3] + PRINT_PS_MASK_B * (256 - p[3])) >> 8;
-				print_job_ps_page_image_pixel(f, bps_buf);
-				}
+			print_job_ps_page_image_pixel(f, p);
 			p+=bps;
 			c++;
 			if (c > 11)
@@ -1851,7 +1836,7 @@ static gint print_job_preview_page_text(PrintWindow *pw, const gchar *text, gdou
 static gint print_job_preview_init(PrintWindow *pw)
 {
 	if (pw->job_pixbuf) g_object_unref(pw->job_pixbuf);
-	pw->job_pixbuf = pw->layout_image->pixbuf;
+	pw->job_pixbuf = image_get_pixbuf(pw->layout_image);
 	g_object_ref(pw->job_pixbuf);
 
 	return print_job_preview_page_new(pw, pw->job_page);
