@@ -194,6 +194,9 @@ void save_options(void)
 	fprintf(f,"#                         GQview config file         version %7s #\n", VERSION);
 	fprintf(f,"######################################################################\n");
 	fprintf(f,"\n");
+	fprintf(f,"# Note: This file is autogenerated. Options can be changed here,\n");
+	fprintf(f,"#       but user comments and formatting will be lost.\n");
+	fprintf(f,"\n");
 	fprintf(f,"##### General Options #####\n\n");
 
 	write_int_option(f, "layout_style", layout_style);
@@ -303,7 +306,7 @@ void save_options(void)
 	filter_write_list(f);
 
 	fprintf(f,"\n##### External Programs #####\n");
-	fprintf(f,"# Maximum of 8 programs (external_1 through external 8)\n");
+	fprintf(f,"# Maximum of 10 programs (external_1 through external_10)\n");
 	fprintf(f,"# format: external_n: \"menu name\" \"command line\"\n\n");
 
 	for (i = 0; i < GQVIEW_EDITOR_SLOTS; i++)
