@@ -613,7 +613,7 @@ GtkWidget *pref_table_box(GtkWidget *table, gint column, gint row,
 		}
 
 	gtk_table_attach(GTK_TABLE(table), shell, column, column + 1, row, row + 1,
-			 GTK_EXPAND | GTK_FILL, 0, 0, 0);
+			 GTK_EXPAND | GTK_FILL, FALSE, 0, 0);
 
 	gtk_widget_show(shell);
 
@@ -628,7 +628,7 @@ GtkWidget *pref_table_label(GtkWidget *table, gint column, gint row,
 
 	align = gtk_alignment_new(alignment, 0.50, 0.0, 0.0);
 	gtk_table_attach(GTK_TABLE(table), align, column, column + 1, row, row + 1,
-			 GTK_FILL, 0, 0, 0);
+			 GTK_FILL, FALSE, 0, 0);
 	gtk_widget_show(align);
 	label = gtk_label_new(text);
 	gtk_container_add(GTK_CONTAINER(align), label);
@@ -645,7 +645,7 @@ GtkWidget *pref_table_button(GtkWidget *table, gint column, gint row,
 
 	button = pref_button_new(NULL, stock_id, text, hide_stock_text, func, data);
 	gtk_table_attach(GTK_TABLE(table), button, column, column + 1, row, row + 1,
-			 GTK_FILL, 0, 0, 0);
+			 GTK_FILL, FALSE, 0, 0);
 	gtk_widget_show(button);
 
 	return button;
@@ -738,17 +738,8 @@ GtkWidget *pref_toolbar_new(GtkWidget *parent_box, GtkToolbarStyle style)
 		}
 
 	tips = gtk_tooltips_new();
-
-	/* take ownership of tooltips */
-#ifdef GTK_OBJECT_FLOATING
-	/* GTK+ < 2.10 */
 	g_object_ref(G_OBJECT(tips));
-	gtk_object_sink(GTK_OBJECT(tips));
-#else
-	/* GTK+ >= 2.10 */
-	g_object_ref_sink(G_OBJECT(tips));
-#endif
-
+        gtk_object_sink(GTK_OBJECT(tips));
 	g_object_set_data(G_OBJECT(tbar), "tooltips", tips);
 	g_signal_connect(G_OBJECT(tbar), "destroy",
 			 G_CALLBACK(pref_toolbar_destroy_cb), tips);
@@ -758,13 +749,37 @@ GtkWidget *pref_toolbar_new(GtkWidget *parent_box, GtkToolbarStyle style)
 	return tbar;
 }
 
-GtkWidget *pref_toolbar_button(GtkWidget *toolbar, const gchar *stock_id, const gchar *label,
+GtkWidget *pref_toolbar_button(GtkWidget *toolbar,
+			       const gchar *stock_id, const gchar *label, gint toggle,
 			       const gchar *description,
 			       GCallback func, gpointer data)
 {
 	GtkWidget *item;
 
-	item = GTK_WIDGET(gtk_tool_button_new_from_stock(stock_id));
+	if (toggle)
+		{
+		if (stock_id)
+			{
+			item = GTK_WIDGET(gtk_toggle_tool_button_new_from_stock(stock_id));
+			}
+		else
+			{
+			item = GTK_WIDGET(gtk_toggle_tool_button_new());
+			}
+		}
+	else
+		{
+		if (stock_id)
+			{
+			item = GTK_WIDGET(gtk_tool_button_new_from_stock(stock_id));
+			}
+		else
+			{
+			item = GTK_WIDGET(gtk_tool_button_new(NULL, NULL));
+			}
+		}
+	gtk_tool_button_set_use_underline(GTK_TOOL_BUTTON(item), TRUE);
+
 	if (label) gtk_tool_button_set_label(GTK_TOOL_BUTTON(item), label);
 
 	if (func) g_signal_connect(item, "clicked", func, data);
@@ -782,6 +797,18 @@ GtkWidget *pref_toolbar_button(GtkWidget *toolbar, const gchar *stock_id, const
 	return item;
 }
 
+void pref_toolbar_button_set_icon(GtkWidget *button, GtkWidget *widget, const gchar *stock_id)
+{
+	if (widget)
+		{
+		gtk_tool_button_set_icon_widget(GTK_TOOL_BUTTON(button), widget);
+		}
+	else if (stock_id)
+		{
+		gtk_tool_button_set_stock_id(GTK_TOOL_BUTTON(button), stock_id);
+		}
+}
+
 GtkWidget *pref_toolbar_spacer(GtkWidget *toolbar)
 {
 	GtkWidget *item;
@@ -872,7 +899,7 @@ static gint date_selection_popup_press_cb(GtkWidget *widget, GdkEventButton *eve
 
 static void date_selection_popup_sync(DateSelection *ds)
 {
-	guint day, month, year;
+	gint day, month, year;
 
 	gtk_calendar_get_date(GTK_CALENDAR(ds->calendar), &year, &month, &day);
 	date_selection_set(ds->box, day, month + 1, year);
